@@ -14,6 +14,7 @@ from .domain.model import (
     AbstractTraceContext,
     CacheControlPolicy,
     CollectionIterator,
+    CollectionParser,
     HeaderField,
     HTTPTimeout,
     JsonSerializer,
@@ -25,6 +26,7 @@ from .domain.model import (
     Response,
     ResponseBox,
 )
+from .domain.model.http import HTTPRequest, HTTPResponse
 from .domain.registry import register
 from .domain.scanner import scan
 from .middleware._async import (
@@ -49,13 +51,21 @@ from .middleware._sync import (
     SyncMiddleware,
     SyncPrometheusMiddleware,
 )
-from .sd._async.adapters.consul import AsyncConsulDiscovery
-from .sd._async.adapters.router import AsyncRouterDiscovery
-from .sd._async.adapters.static import AsyncStaticDiscovery
-from .sd._sync.adapters.consul import SyncConsulDiscovery
-from .sd._sync.adapters.router import SyncRouterDiscovery
-from .sd._sync.adapters.static import SyncStaticDiscovery
+from .sd._async import (
+    AsyncAbstractServiceDiscovery,
+    AsyncConsulDiscovery,
+    AsyncRouterDiscovery,
+    AsyncStaticDiscovery,
+)
+from .sd._sync import (
+    SyncAbstractServiceDiscovery,
+    SyncConsulDiscovery,
+    SyncRouterDiscovery,
+    SyncStaticDiscovery,
+)
+from .service._async.base import AsyncAbstractTransport
 from .service._async.client import AsyncClient, AsyncClientFactory
+from .service._sync.base import SyncAbstractTransport
 from .service._sync.client import SyncClient, SyncClientFactory
 
 __all__ = [
@@ -73,6 +83,7 @@ __all__ = [
     "ResponseBox",
     "CollectionIterator",
     "AbstractCollectionParser",
+    "CollectionParser",
     # Exceptions
     "HTTPError",
     "HTTPTimeoutError",
@@ -84,6 +95,8 @@ __all__ = [
     "AsyncClient",
     "SyncClient",
     # Service Discovery
+    "AsyncAbstractServiceDiscovery",
+    "SyncAbstractServiceDiscovery",
     "AsyncConsulDiscovery",
     "SyncConsulDiscovery",
     "AsyncRouterDiscovery",
@@ -117,4 +130,9 @@ __all__ = [
     "SyncHTTPCacheMiddleware",
     "AbstractTraceContext",
     "AsyncZipkinMiddleware",
+    # Transport
+    "AsyncAbstractTransport",
+    "SyncAbstractTransport",
+    "HTTPRequest",
+    "HTTPResponse",
 ]
