@@ -1,4 +1,12 @@
 from .http import HTTPRequest, HTTPResponse, HTTPTimeout
+from .middleware.http_cache import (
+    AbstractCachePolicy,
+    AbstractSerializer,
+    CacheControlPolicy,
+    JsonSerializer,
+)
+from .middleware.prometheus import PrometheusMetrics
+from .middleware.zipkin import AbstractTraceContext
 from .params import (
     AbstractCollectionParser,
     CollectionIterator,
@@ -12,13 +20,8 @@ from .params import (
     ResponseBox,
     TResponse,
 )
-from .tracing import AbtractTraceContext
 
 __all__ = [
-    "AbtractTraceContext",
-    "AbstractCollectionParser",
-    "CollectionIterator",
-    "CollectionParser",
     "HeaderField",
     "HTTPRequest",
     "HTTPResponse",
@@ -30,4 +33,13 @@ __all__ = [
     "Response",
     "ResponseBox",
     "TResponse",
+    "AbstractCollectionParser",
+    "CollectionParser",
+    "CollectionIterator",
+    "AbstractSerializer",
+    "JsonSerializer",
+    "AbstractCachePolicy",
+    "CacheControlPolicy",
+    "PrometheusMetrics",
+    "AbstractTraceContext",
 ]
